==> xara-0.0.1.tar.gz: xara-0.0.1/SRC/material/elastic/ElasticIsotropicBeamFiber.h <==
/* ****************************************************************** **
**    OpenSees - Open System for Earthquake Engineering Simulation    **
**          Pacific Earthquake Engineering Research Center            **
**                                                                    **
**                                                                    **
** (C) Copyright 1999, The Regents of the University of California    **
** All Rights Reserved.                                               **
**                                                                    **
** Commercial use of this program without express permission of the   **
** University of California, Berkeley, is strictly prohibited.  See   **
** file 'COPYRIGHT'  in main directory for information on usage and   **
** redistribution,  and for a DISCLAIMER OF ALL WARRANTIES.           **
**                                                                    **
** Developed by:                                                      **
**   Frank McKenna (fmckenna@ce.berkeley.edu)                         **
**   Gregory L. Fenves (fenves@ce.berkeley.edu)                       **
**   Filip C. Filippou (filippou@ce.berkeley.edu)                     **
**                                                                    **
** ****************************************************************** */
//
// Description: Elastic isotropic model where stress components 22, 33, and 23
// are condensed out.
//
// Written: MHS
// Created: Aug 2001
// //
#ifndef ElasticIsotropicBeamFiber_h
#define ElasticIsotropicBeamFiber_h

#include <ElasticIsotropicMaterial.h>

#include <Matrix.h>
#include <Vector.h>
#include <ID.h>
#include <Information.h>
#include <Parameter.h>

class ElasticIsotropicBeamFiber : public ElasticIsotropicMaterial
{
  public:
    ElasticIsotropicBeamFiber (int tag, double E, double nu, double rho);
    ElasticIsotropicBeamFiber ();
    ~ElasticIsotropicBeamFiber ();

    int setTrialStrain (const Vector &v);
    int setTrialStrain (const Vector &v, const Vector &r);
    int setTrialStrainIncr (const Vector &v);
    int setTrialStrainIncr (const Vector &v, const Vector &r);
    const Matrix &getTangent (void);
    const Matrix &getInitialTangent (void);
    const Vector &getStress (void);
    const Vector &getStrain (void);
        
    int commitState (void);
    int revertToLastCommit (void);
    int revertToStart (void);
    
    NDMaterial *getCopy (void);
    const char *getType (void) const;
    int getOrder (void) const;
    
    const Vector& getStressSensitivity(int gradIndex,
				       bool conditional);
  protected:

  private:
    static Vector sigma;	// Stress vector ... class-wide for returns
    static Matrix D;		// Elastic constants
    Vector Tepsilon;		// Trial strains
};


#endif

==> xara-0.0.3.tar.gz: xara-0.0.3/SRC/material/elastic/ElasticIsotropicBeamFiber.h <==
/* ****************************************************************** **
**    OpenSees - Open System for Earthquake Engineering Simulation    **
**          Pacific Earthquake Engineering Research Center            **
**                                                                    **
**                                                                    **
** (C) Copyright 1999, The Regents of the University of California    **
** All Rights Reserved.                                               **
**                                                                    **
** Commercial use of this program without express permission of the   **
** University of California, Berkeley, is strictly prohibited.  See   **
** file 'COPYRIGHT'  in main directory for information on usage and   **
** redistribution,  and for a DISCLAIMER OF ALL WARRANTIES.           **
**                                                                    **
** Developed by:                                                      **
**   Frank McKenna (fmckenna@ce.berkeley.edu)                         **
**   Gregory L. Fenves (fenves@ce.berkeley.edu)                       **
**   Filip C. Filippou (filippou@ce.berkeley.edu)                     **
**                                                                    **
** ****************************************************************** */
//
// Description: Elastic isotropic model where stress components 22, 33, and 23
// are condensed out.
//
// Written: MHS
// Created: Aug 2001
// //
#ifndef ElasticIsotropicBeamFiber_h
#define ElasticIsotropicBeamFiber_h

#include <ElasticIsotropicMaterial.h>

#include <Matrix.h>
#include <Vector.h>
#include <ID.h>
#include <Information.h>
#include <Parameter.h>

class ElasticIsotropicBeamFiber : public ElasticIsotropicMaterial
{
  public:
    ElasticIsotropicBeamFiber (int tag, double E, double nu, double rho);
    ElasticIsotropicBeamFiber ();
    ~ElasticIsotropicBeamFiber ();

    int setTrialStrain (const Vector &v);
    int setTrialStrain (const Vector &v, const Vector &r);
    int setTrialStrainIncr (const Vector &v);
    int setTrialStrainIncr (const Vector &v, const Vector &r);
    const Matrix &getTangent();
    const Matrix &getInitialTangent();
    const Vector &getStress();
    const Vector &getStrain();
        
    int commitState (void);
    int revertToLastCommit (void);
    int revertToStart (void);
    
    NDMaterial *getCopy (void);
    const char *getType (void) const;
    int getOrder (void) const;
    
    const Vector& getStressSensitivity(int gradIndex,
				       bool conditional);
  protected:

  private:
    static Vector sigma;	// Stress vector ... class-wide for returns
    static Matrix D;		// Elastic constants
    Vector Tepsilon;		// Trial strains
};


#endif
